# -*- coding: utf-8 -*-


class MacroRuntime(object):

    # nodejs 6.10
    node610 = "nodejs6.10"
    cmd_node610 = "node"

    # nodejs 8.9
    node89 = "nodejs8.9"
    cmd_node89 = "node"

    # nodejs 8.9 -service
    node89_s = "nodejs8.9-service"
    cmd_node89_s = "node"

    # python3.6
    python36 = "python3.6"
    cmd_python36 = "python"

    # python2.7
    python27 = "python2.7"
    cmd_python27 = "python"